@@ -438,7 +438,7 @@ class Segment:
         -------
         `tuple` :code:`(range, array)`
 
-            * :code:`range` of length `JR`: relative index range of window with respect to semgent's boundaries.
+            * :code:`range` of length `JR`: relative index range of window with respect to segment's boundaries.
             * :code:`array` of shape=(JR) of floats: per-index window weight over the reported index range
 
 
@@ -453,13 +453,13 @@ class Segment:
         """
 
         if self.direction == FW:
-            a_lim = max(np.log(thd) / np.log(self.gamma) - 1, self.a)
+            a_lim = max(np.log(thd) / np.log(self.gamma) - 1 +self.delta, self.a)
             b_lim = self.b
         else:  # self.direction == BW:
             a_lim = self.a
-            b_lim = min(np.log(thd) / np.log(self.gamma) + 1, self.b)
+            b_lim = min(np.log(thd) / np.log(self.gamma) + 1+self.delta, self.b)
         ab_range = range(int(a_lim), int(b_lim)+1)
-        return ab_range, np.power(self.gamma, np.array(ab_range)-self.delta)
+        return ab_range, self.gamma**(np.array(ab_range)-self.delta)
 
 
 class CostBase(ABC):
@@ -591,12 +591,12 @@ class CostBase(ABC):
         """
         Returns for each selected segment its window generated by :meth:`CostSegment.windows`.
 
-        The segments are selcted by :attr:`segment_selection`.
+        The segments are selected by :attr:`segment_selection`.
 
 
         Parameters
         ----------
-        segment_selection : array_like, shape=(P,) of Boolean
+        segment_indices : array_like, shape=(P,) of Boolean
             Enables (:code:`True`, 1) or disables (:code:`False`, 0) the evaluation of the
             p-th Segment in :attr:`CompositeCost.segments` using :meth:`CostSegment.window`
         thds : list of shape=(P,) of floats, scalar, optional
